==> crunchyfrog-0.2.1.tar.gz: crunchyfrog-0.2.1/cf/release.py <==
# -*- coding: utf-8 -*-

# crunchyfrog - a database schema browser and query tool
# Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# $Id: release.py 188 2008-06-10 05:02:41Z albrecht.andi $

"""Release information"""

name = "CrunchyFrog"
appname = name.lower()
version = "0.2.1"
copyright = "Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>"
description = "Database navigator and query tool for GNOME"
author = "Andi Albrecht"
author_email = "albrecht.andi@gmail.com"
url = "http://cf.andialbrecht.de"
long_description = """CrunchyFrog is a database navigator and SQL editor 
for the GNOME desktop.

Supported databases
===================

 * PostgreSQL (requires psycopg2)
 * MySQL (requires MySQLdb)
 * SQLite3 (requires python-sqlite3)
 * Oracle (requires cx_Oracle)
 * LDAP (requires python-ldap)

It is written in Python (PyGTK) and can be extended using plugins.

Check out the homepage for the most recent version and details."""
license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""

translators="""Launchpad Contributions:
  Kari Argillander (https://launchpad.net/~kari-argillander)
  Anthony Guéchoum (https://launchpad.net/~athael)
  Luca Livraghi (https://launchpad.net/~luca91)
  Nicola Piovesan (https://launchpad.net/~piovesannicola)
  Xoan Sampaiño (https://launchpad.net/~xoan)
"""

==> crunchyfrog-0.3.0.tar.gz: crunchyfrog-0.3.0/cf/release.py <==
# -*- coding: utf-8 -*-

# crunchyfrog - a database schema browser and query tool
# Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# $Id$

"""Release information"""

name = "CrunchyFrog"
appname = name.lower()
version = "0.3.0"
copyright = "Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>"
description = "Database front-end for GNOME"
author = "Andi Albrecht"
author_email = "albrecht.andi@gmail.com"
url = "http://cf.andialbrecht.de"
long_description = """CrunchyFrog is a database front-end for the GNOME desktop.

Supported databases
===================

 * PostgreSQL (requires psycopg2)
 * MySQL (requires MySQLdb)
 * SQLite3 (requires python-sqlite3)
 * Oracle (requires cx_Oracle)
 * MS-SQL Server (requires pymssql)
 * LDAP (requires python-ldap)

It is written in Python (PyGTK) and can be extended using plugins.

Check out the homepage for the most recent version and details."""

license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""

translators="""Launchpad Contributions:
  Kari Argillander (https://launchpad.net/~kari-argillander)
  Edwin Dijk (https://launchpad.net/~sitix)
  Anthony Guéchoum (https://launchpad.net/~athael)
  Guybrush88 (https://launchpad.net/~erpizzo)
  Ryutatsu Ishigami (https://launchpad.net/~ai-inside+ubuntu)
  Luca Livraghi (https://launchpad.net/~luca91)
  Marion Cisternas Milla (https://launchpad.net/~mcisternas)
  Christian Olate Opazo (https://launchpad.net/~cristian-olate)
  Penegal (https://launchpad.net/~penegal)
  Nicola Piovesan (https://launchpad.net/~piovesannicola)
  Enrico Rosina (https://launchpad.net/~e-rosina)
  Xoan Sampaiño (https://launchpad.net/~xoan)
  Skiros (https://launchpad.net/~magoskiros)
  Pierre Slamich (https://launchpad.net/~pierre-slamich)
  Jeppe Toustrup (https://launchpad.net/~tenzer)
  ubby (https://launchpad.net/~kostas-sytske)
  Linus C Unneback (https://launchpad.net/~linus-folkdatorn)
  Yaron (https://launchpad.net/~sh-yaron)
  Muhammad Zulfikar (https://launchpad.net/~zulfikars)
  0x00080h (https://launchpad.net/~einstein89)
"""
